@@ -292,7 +292,7 @@ class Canvas:
     # draw arc on canvas
     def arc(self, x1, y1, x2, y2, start, extend):
         return self.handle.create_arc(self.transform_coords([[x1, y1], [x2, y2]]),
-                                      extent = -extend,
+                                      extent = extend,
                                       start = -start,
                                       style = tk.ARC,
                                       outline = self.__parameters()['stroke_color'],
@@ -423,6 +423,12 @@ class Canvas:
     def __parameters(self):
         return self.__hist[len(self.__hist) - 1]
 
+    def bring_to_front(self, item):
+        self.handle.tag_lower(item)
+
+    def send_to_back(self, item):
+        self.handle.tag_raise(item)
+
     # push current parameters
     def push(self):
         self.__hist.append(self.__parameters().copy())
